@@ -1,4 +1,4 @@
-/* $Id: union.h,v 1.10 1999/02/23 11:43:23 martin Exp $ */
+/* $Id: union.h,v 1.19 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -50,7 +50,7 @@
 #include <glibtop/netload.h>
 #include <glibtop/ppp.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 typedef union _glibtop_union	glibtop_union;
 
@@ -80,6 +80,6 @@ union _glibtop_union
 	glibtop_ppp		ppp;
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
