@@ -20,20 +20,11 @@
 # include <config.h>
 #endif
 
-#if HAVE_INTTYPES_H
-# include <inttypes.h>
-#else
-# if HAVE_STDINT_H
-#  include <stdint.h>
-# endif
-#endif
-#ifndef UINTMAX_MAX
-# define UINTMAX_MAX ((uintmax_t) -1)
-#endif
+#include <glibtop.h>
+#include <glibtop/fsusage.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include "fsusage.h"
 
 #if HAVE_LIMITS_H
 # include <limits.h>
@@ -81,23 +72,23 @@ int statvfs ();
 
 /* Many space usage primitives use all 1 bits to denote a value that is
    not applicable or unknown.  Propagate this information by returning
-   a uintmax_t value that is all 1 bits if X is all 1 bits, even if X
-   is unsigned and narrower than uintmax_t.  */
+   a guint64 value that is all 1 bits if X is all 1 bits, even if X
+   is unsigned and narrower than guint64.  */
 #define PROPAGATE_ALL_ONES(x) \
-  ((sizeof (x) < sizeof (uintmax_t) \
+  ((sizeof (x) < sizeof (guint64) \
     && (~ (x) == (sizeof (x) < sizeof (int) \
 		  ? - (1 << (sizeof (x) * CHAR_BIT)) \
 		  : 0))) \
-   ? UINTMAX_MAX : (x))
+   ? G_MAXUINT64 : (x))
 
-/* Extract the top bit of X as an uintmax_t value.  */
+/* Extract the top bit of X as an guint64 value.  */
 #define EXTRACT_TOP_BIT(x) ((x) \
-			    & ((uintmax_t) 1 << (sizeof (x) * CHAR_BIT - 1)))
+			    & ((guint64) 1 << (sizeof (x) * CHAR_BIT - 1)))
 
 /* If a value is negative, many space usage primitives store it into an
    integer variable by assignment, even if the variable's type is unsigned.
    So, if a space usage variable X's top bit is set, convert X to the
-   uintmax_t value V such that (- (uintmax_t) V) is the negative of
+   guint64 value V such that (- (guint64) V) is the negative of
    the original value.  If X's top bit is clear, just yield X.
    Use PROPAGATE_TOP_BIT if the original value might be negative;
    otherwise, use PROPAGATE_ALL_ONES.  */
@@ -110,17 +101,66 @@ int statvfs ();
    Return 0 if successful, -1 if not.  When returning -1, ensure that
    ERRNO is either a system error value, or zero if DISK is NULL
    on a system that requires a non-NULL value.  */
-int
-glibtop_private_get_fs_usage (const char *path, const char *disk, struct fs_usage *fsp)
+
+
+static const unsigned long _glibtop_sysdeps_fsusage =
+(1L << GLIBTOP_FSUSAGE_BLOCKS) + (1L << GLIBTOP_FSUSAGE_BFREE)
++ (1L << GLIBTOP_FSUSAGE_BAVAIL) + (1L << GLIBTOP_FSUSAGE_FILES)
++ (1L << GLIBTOP_FSUSAGE_FFREE) + (1L << GLIBTOP_FSUSAGE_BLOCK_SIZE);
+
+
+
+/*
+ * _glibtop_get_fsusage_read_write
+ * New function to retrieve total read and write
+ *
+ * Each arch should have its own function()
+ * and the proper #define. This is more readable than one single
+ * function full of #something where everything is mixed.
+ * These functions are private.
+ *
+ * void _glibtop_<arch>_get_fsusage_read_write(glibtop*server,
+ *                                               glibtop_fsusage *buf,
+ *                                               const char *path);
+ *
+ * TODO: split this file properly, is possible
+ */
+
+#ifdef linux
+void _glibtop_linux_get_fsusage_read_write(glibtop *server,
+					     glibtop_fsusage *buf,
+					     const char *path);
+
+#define _glibtop_get_fsusage_read_write(S, B, P) \
+        _glibtop_linux_get_fsusage_read_write(S, B, P)
+
+
+#else /* default fallback */
+#define _glibtop_get_fsusage_read_write(S, B, P) ((void)0)
+#endif
+
+/* end _glibtop_get_fsusage_read_write */
+
+
+
+void
+glibtop_get_fsusage_s (glibtop *server, glibtop_fsusage *buf,
+		       const char *path)
 {
+  glibtop_init_r (&server, 0, 0);
+
+  memset (buf, 0, sizeof (glibtop_fsusage));
+
+  _glibtop_get_fsusage_read_write(server, buf, path);
+
 #ifdef STAT_STATFS3_OSF1
 
   struct statfs fsd;
 
   if (statfs (path, &fsd, sizeof (struct statfs)) != 0)
-    return -1;
+    return;
 
-  fsp->fsu_blocksize = PROPAGATE_ALL_ONES (fsd.f_fsize);
+  buf->block_size = PROPAGATE_ALL_ONES (fsd.f_fsize);
 
 #endif /* STAT_STATFS3_OSF1 */
 
@@ -129,15 +169,15 @@ glibtop_private_get_fs_usage (const char *path, const char *disk, struct fs_usag
   struct fs_data fsd;
 
   if (statfs (path, &fsd) != 1)
-    return -1;
+    return;
 
-  fsp->fsu_blocksize = 1024;
-  fsp->fsu_blocks = PROPAGATE_ALL_ONES (fsd.fd_req.btot);
-  fsp->fsu_bfree = PROPAGATE_ALL_ONES (fsd.fd_req.bfree);
-  fsp->fsu_bavail = PROPAGATE_TOP_BIT (fsd.fd_req.bfreen);
-  fsp->fsu_bavail_top_bit_set = EXTRACT_TOP_BIT (fsd.fd_req.bfreen) != 0;
-  fsp->fsu_files = PROPAGATE_ALL_ONES (fsd.fd_req.gtot);
-  fsp->fsu_ffree = PROPAGATE_ALL_ONES (fsd.fd_req.gfree);
+  buf->block_size = 1024;
+  buf->blocks = PROPAGATE_ALL_ONES (fsd.fd_req.btot);
+  buf->bfree = PROPAGATE_ALL_ONES (fsd.fd_req.bfree);
+  buf->bavail = PROPAGATE_TOP_BIT (fsd.fd_req.bfreen);
+  // buf->bavail_top_bit_set = EXTRACT_TOP_BIT (fsd.fd_req.bfreen) != 0;
+  buf->files = PROPAGATE_ALL_ONES (fsd.fd_req.gtot);
+  buf->ffree = PROPAGATE_ALL_ONES (fsd.fd_req.gfree);
 
 #endif /* STAT_STATFS2_FS_DATA */
 
@@ -146,9 +186,9 @@ glibtop_private_get_fs_usage (const char *path, const char *disk, struct fs_usag
   struct statfs fsd;
 
   if (statfs (path, &fsd) < 0)
-    return -1;
+    return;
 
-  fsp->fsu_blocksize = PROPAGATE_ALL_ONES (fsd.f_bsize);
+  buf->block_size = PROPAGATE_ALL_ONES (fsd.f_bsize);
 
 # ifdef STATFS_TRUNCATES_BLOCK_COUNTS
 
@@ -172,9 +212,9 @@ glibtop_private_get_fs_usage (const char *path, const char *disk, struct fs_usag
   struct statfs fsd;
 
   if (statfs (path, &fsd) < 0)
-    return -1;
+    return;
 
-  fsp->fsu_blocksize = PROPAGATE_ALL_ONES (fsd.f_fsize);
+  buf->block_size = PROPAGATE_ALL_ONES (fsd.f_fsize);
 
 #endif /* STAT_STATFS2_FSIZE */
 
@@ -187,15 +227,15 @@ glibtop_private_get_fs_usage (const char *path, const char *disk, struct fs_usag
   struct statfs fsd;
 
   if (statfs (path, &fsd, sizeof fsd, 0) < 0)
-    return -1;
+    return;
 
   /* Empirically, the block counts on most SVR3 and SVR3-derived
      systems seem to always be in terms of 512-byte blocks,
      no matter what value f_bsize has.  */
 # if _AIX || defined _CRAY
-   fsp->fsu_blocksize = PROPAGATE_ALL_ONES (fsd.f_bsize);
+   buf->block_size = PROPAGATE_ALL_ONES (fsd.f_bsize);
 # else
-   fsp->fsu_blocksize = 512;
+   buf->block_size = 512;
 # endif
 
 #endif /* STAT_STATFS4 */
@@ -205,10 +245,10 @@ glibtop_private_get_fs_usage (const char *path, const char *disk, struct fs_usag
   struct statvfs fsd;
 
   if (statvfs (path, &fsd) < 0)
-    return -1;
+    return;
 
   /* f_frsize isn't guaranteed to be supported.  */
-  fsp->fsu_blocksize = (fsd.f_frsize
+  buf->block_size = (fsd.f_frsize
 			? PROPAGATE_ALL_ONES (fsd.f_frsize)
 			: PROPAGATE_ALL_ONES (fsd.f_bsize));
 
@@ -217,23 +257,23 @@ glibtop_private_get_fs_usage (const char *path, const char *disk, struct fs_usag
 #if !defined STAT_STATFS2_FS_DATA && !defined STAT_READ_FILSYS
 				/* !Ultrix && !SVR2 */
 
-  fsp->fsu_blocks = PROPAGATE_ALL_ONES (fsd.f_blocks);
-  fsp->fsu_bfree = PROPAGATE_ALL_ONES (fsd.f_bfree);
-  fsp->fsu_bavail = PROPAGATE_TOP_BIT (fsd.f_bavail);
-  fsp->fsu_bavail_top_bit_set = EXTRACT_TOP_BIT (fsd.f_bavail) != 0;
-  fsp->fsu_files = PROPAGATE_ALL_ONES (fsd.f_files);
-  fsp->fsu_ffree = PROPAGATE_ALL_ONES (fsd.f_ffree);
+  buf->blocks = PROPAGATE_ALL_ONES (fsd.f_blocks);
+  buf->bfree = PROPAGATE_ALL_ONES (fsd.f_bfree);
+  buf->bavail = PROPAGATE_TOP_BIT (fsd.f_bavail);
+  // buf->bavail_top_bit_set = EXTRACT_TOP_BIT (fsd.f_bavail) != 0;
+  buf->files = PROPAGATE_ALL_ONES (fsd.f_files);
+  buf->ffree = PROPAGATE_ALL_ONES (fsd.f_ffree);
 
 #endif /* not STAT_STATFS2_FS_DATA && not STAT_READ_FILSYS */
 
-  return 0;
+  buf->flags= _glibtop_sysdeps_fsusage;
 }
 
 #if defined _AIX && defined _I386
 /* AIX PS/2 does not supply statfs.  */
 
 static int
-statfs (char *path, struct statfs *fsb)
+statfs (const char *path, struct statfs *fsb)
 {
   struct stat stats;
   struct dustat fsd;
