@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.34 2005/12/13 09:15:49 bdejean Exp $ */
+/* $Id: proctime.c,v 1.26 2004/06/09 18:52:21 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,17 +21,12 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/proctime.h>
-#include <glibtop/uptime.h>
-
-#include "glibtop_private.h"
 
 static const unsigned long _glibtop_sysdeps_proc_time =
 (1L << GLIBTOP_PROC_TIME_UTIME) + (1L << GLIBTOP_PROC_TIME_CUTIME) +
-(1L << GLIBTOP_PROC_TIME_RTIME) +
 (1L << GLIBTOP_PROC_TIME_STIME) + (1L << GLIBTOP_PROC_TIME_CSTIME) +
 (1L << GLIBTOP_PROC_TIME_FREQUENCY) + (1L << GLIBTOP_PROC_TIME_TIMEOUT) +
 (1L << GLIBTOP_PROC_TIME_IT_REAL_VALUE) + (1L << GLIBTOP_PROC_TIME_START_TIME);
@@ -70,44 +65,16 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid)
 
 	p = skip_multiple_token (p, 11);
 
-	/* clock_t  (1/100 s) */
 	buf->utime  = strtoull (p, &p, 0);
 	buf->stime  = strtoull (p, &p, 0);
-	buf->rtime = buf->utime + buf->stime;
-
 	buf->cutime = strtoull (p, &p, 0);
 	buf->cstime = strtoull (p, &p, 0);
 
-	p = skip_multiple_token (p, 3);
+	p = skip_multiple_token (p, 2);
 
-	/* timeout is 0 on 2.4 and "thread_number" on 2.6
-	   lets skip it (using previous skip_multiple_token)
-	   buf->timeout       = strtoull (p, &p, 0);
-	*/
+	buf->timeout       = strtoull (p, &p, 0);
 	buf->it_real_value = strtoull (p, &p, 0);
-
-	/* seconds since epoch */
-	{
-	  /*
-	     See libgtop documentation.
-
-	     #ifdef __KERNEL__
-	     ...
-	     *
-	     * Have the 32 bit jiffies value wrap 5 minutes after boot
-	     * so jiffies wrap bugs show up earlier.
-	     *
-	     #define INITIAL_JIFFIES ((unsigned long)(unsigned int) (-300*HZ))
-	     ...
-	     #endif
-
-	     start_time may be incremented by INITIAL_JIFFIES, so start_time
-	     may be not be exact. You may also get wrong start_time if your
-	     system clock is not synchronised with you hardware clock.
-	     'man hwclock'
-	  */
-	  buf->start_time = get_boot_time(server) + strtoull (p, &p, 0) / 100;
-	}
+	buf->start_time    = strtoull (p, &p, 0);
 
 	buf->frequency = 100;
 
@@ -116,18 +83,18 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid)
 	if (!server->ncpu)
 		return;
 
-	/* FIXME: doesn't work with 2.6 */
 	if (proc_file_to_buffer (buffer, "/proc/%d/cpu", pid))
 		return;
 
-	p = skip_multiple_token (p, 3);
+	p = skip_token (buffer);
+	buf->utime  = strtoull (p, &p, 0);
+	buf->stime  = strtoull (p, &p, 0);
 
-	for (i = 0; i <= server->ncpu; i++) {
-
-		if (!check_cpu_line_warn(server, p + 1, i))
+	for (i = 0; i < GLIBTOP_NCPU; i++) {
+		if (strncmp (p+1, "cpu", 3) || !isdigit (p [4]))
 			break;
 
-		p = skip_token(p);
+		p += 6;
 		buf->xcpu_utime [i] = strtoull (p, &p, 0);
 		buf->xcpu_stime [i] = strtoull (p, &p, 0);
 	}
