@@ -1,4 +1,4 @@
-/* $Id: procuid.c,v 1.10 2003/10/20 21:27:27 hadess Exp $ */
+/* $Id: procuid.c,v 1.12 2004/06/09 18:52:22 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,11 +23,11 @@
 
 #include <glibtop.h>
 #include <glibtop/procuid.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 const char *glibtop_names_proc_uid [GLIBTOP_MAX_PROC_UID] =
 {
-	"uid", "euid", "gid", "egid", "suid", "sgid", 
+	"uid", "euid", "gid", "egid", "suid", "sgid",
 	"fsuid", "fsgid", "pid", "ppid", "pgrp",
 	"session", "tty", "tpgid", "priority", "nice",
 	"ngroups", "groups"
